@@ -3,6 +3,7 @@ import os
 import subprocess
 import time
 import uuid
+import warnings
 from os.path import join as jp
 
 from pysgems.utils.sgutils import joinlist
@@ -10,7 +11,30 @@ from pysgems.utils.sgutils import joinlist
 
 class Sgems:
 
-    def __init__(self, project_name='sgems_test', project_wd='', res_dir='', script_dir='', nodata=-9966699, **kwargs):
+    def __init__(self,
+                 project_name='sgems_test',
+                 project_wd='',
+                 res_dir='',
+                 script_dir='',
+                 exe_name='',
+                 nodata=-9966699,
+                 check_env=True,
+                 **kwargs):
+
+        if check_env:
+            # First check if sgems installation files are in the user environment variables
+            gstl_home = os.environ.get('GSTLAPPLIHOME')
+            if not gstl_home:
+                warnings.warn('GSTLAPPLIHOME environment variable does not exist')
+            else:
+                path = os.getenv('Path')
+                if gstl_home not in path:
+                    warnings.warn('Variable {} does not exist in Path environment variable'.format(gstl_home))
+                if not exe_name:  # If no sgems exe file name is provided,
+                    # checks for sgems exe file in the GSTLAPPLIHOME path
+                    for file in os.listdir(gstl_home):
+                        if file.endswith(".exe") and ('sgems' in file) and ('uninstall' not in file):
+                            exe_name = file
 
         self.project_name = project_name
 
@@ -26,6 +50,8 @@ class Sgems:
         if not os.path.exists(self.res_dir):
             os.makedirs(self.res_dir)
 
+        self.exe_name = exe_name
+
         self.dis = None  # Discretization instance
         self.point_set = None  # Point set manager instance
         self.algo = None  # XML manipulation instance
@@ -49,9 +75,14 @@ class Sgems:
         # within its python environment
         try:
             name = self.algo.root.find('algorithm').attrib['name']  # Algorithm name
-            name_op = name
-            if name == 'sgsim':
-                name_op += '__real0'
+            try:
+                # When performing simulations, sgems automatically add '__realn'
+                # to the name of the nth generated property.
+                nr = int(self.algo.root.find('Nb_Realizations').attrib['value'])
+                name_op = '::'.join([name + '__real' + str(i) for i in range(nr)])
+            except AttributeError:
+                name_op = name
+
             with open(self.algo.op_file) as alx:  # Remove unwanted \n
                 algo_xml = alx.read().strip('\n')
 
@@ -69,13 +100,14 @@ class Sgems:
         sgems_files = [sf + '.sgems' for sf in self.object_file_names]
 
         # The list below is the list of flags that will be replaced in the sgems python script
+        # TODO: add option to change output file name (now default 'results.grid')
         params = [[run_algo_flag, '#~'],
                   [self.res_dir.replace('\\', '//'), 'RES_DIR'],  # for sgems convention...
                   [grid, 'GRID'],
                   [self.project_name, 'PROJECT_NAME'],
                   ['results', 'FEATURE_OUTPUT'],  # results.grid = output file
                   [name, 'ALGORITHM_NAME'],
-                  [name_op, 'PROPERTY_NAME'],
+                  [name_op, 'OUTPUT_LIST'],
                   [algo_xml, 'ALGORITHM_XML'],
                   [str(sgems_files), 'OBJECT_FILES']]
 
@@ -102,7 +134,7 @@ class Sgems:
         batch = jp(self.res_dir, 'RunSgems.bat')
         bat = open(batch, 'w')
         bat.write(' '.join(['cd', self.res_dir, '\n']))
-        bat.write(' '.join(['sgems', 'sgems.script']))
+        bat.write(' '.join([self.exe_name, 'sgems.script']))
         bat.close()
 
     def run(self):
